@@ -3,6 +3,7 @@
 # This software is released under the MIT License.
 # https://opensource.org/licenses/MIT
 import json
+from re import I
 import time
 import tempfile
 import math
@@ -44,18 +45,6 @@ class Process(ProcessInterface):
 from dask_jobqueue.htcondor import HTCondorJob
 
 
-class Job(HTCondorJob):
-    def __init__(self, *args, **kwargs):
-        super().__init__(
-            *args,
-            **kwargs,
-            python="source /usr/local/share/root6/bin/thisroot.sh ; /usr/bin/python3",
-        )
-        self.submit_command = "./sched_submit.sh"
-        # self._scheduler = "tcp://90.147.75.109:8989"
-        self.executable = "/bin/bash"
-
-
 class Scheduler(Process):
     """A Remote Dask Scheduler controlled via HTCondor
     Parameters
@@ -66,7 +55,7 @@ class Scheduler(Process):
         The port to bind for dask dasahboard
     """
 
-    def __init__(self, sched_port=8989, dashboard_port=8787):
+    def __init__(self, sched_port=8989, dashboard_port=8787, ssh_namespace="default"):
         self.cluster_id = None
         self.name = os.environ.get("JUPYTERHUB_USER") + "-{}.dask-ssh".format(
             sched_port
@@ -76,6 +65,17 @@ class Scheduler(Process):
         ) + "-{}.dash.dask-ssh".format(dashboard_port)
         self.sched_port = sched_port
         self.dash_port = dashboard_port
+        self.sshNamespace = ssh_namespace
+
+        self.htc_ca = "$PWD/ca.crt" 
+        #os.environ.get("_condor_AUTH_SSL_CLIENT_CAFILE")
+        self.htc_debug = os.environ.get("_condor_TOOL_DEBUG")
+        self.htc_collector = os.environ.get("_condor_COLLECTOR_HOST")
+        self.htc_schedd_host = os.environ.get("_condor_SCHEDD_HOST")
+        self.htc_schedd_name = os.environ.get("_condor_SCHEDD_NAME")
+        self.htc_scitoken_file = "$PWD/token"
+        #os.environ.get("_condor_SCITOKENS_FILE")
+        self.htc_sec_method = os.environ.get("_condor_SEC_DEFAULT_AUTHENTICATION_METHODS")
 
         self.token = os.environ.get("JUPYTERHUB_API_TOKEN")
         self.refresh_token = os.environ.get("REFRESH_TOKEN")
@@ -119,8 +119,7 @@ class Scheduler(Process):
             for f in files:
                 tmpl = env.get_template(f)
                 with open(tmpdirname + "/" + f, "w") as dest:
-                    dest.write(
-                        tmpl.render(
+                    render = tmpl.render(
                             name=self.name,
                             token=self.token,
                             sched_port=self.sched_port,
@@ -129,15 +128,23 @@ class Scheduler(Process):
                             iam_server=self.iam_server,
                             client_id=self.client_id,
                             client_secret=self.client_secret,
+                            htc_ca=self.htc_ca,
+                            htc_debug=self.htc_debug,
+                            htc_collector=self.htc_collector,
+                            htc_schedd_host=self.htc_schedd_host,
+                            htc_schedd_name=self.htc_schedd_name,
+                            htc_scitoken_file=self.htc_scitoken_file,
+                            htc_sec_method=self.htc_sec_method
                         )
-                    )
+                    #print(render)
+                    dest.write(render)
 
-            cmd = "source ~/htc.rc; cd {}; condor_submit -spool scheduler.sub".format(
+            cmd = "cd {}; condor_submit -spool scheduler.sub".format(
                 tmpdirname
             )
 
             try:
-                cmd_out = check_output(cmd, stderr=STDOUT, shell=True)
+                cmd_out = check_output(cmd, stderr=STDOUT, shell=True, env=os.environ)
             except Exception as ex:
                 raise ex
 
@@ -152,7 +159,7 @@ class Scheduler(Process):
         job_status = 1
         while job_status == 1:
             time.sleep(30)
-            cmd = "source ~/htc.rc; condor_q {}.0 -json".format(self.cluster_id)
+            cmd = "condor_q {}.0 -json".format(self.cluster_id)
 
             cmd_out = check_output(cmd, stderr=STDOUT, shell=True)
 
@@ -169,7 +176,7 @@ class Scheduler(Process):
                 raise Exception("Scheduler job in error {}".format(job_status))
 
         self.connection = await asyncssh.connect(
-            "listener.htcondor.svc.cluster.local",
+            "ssh-listener.%s.svc.cluster.local" % self.sshNamespace,
             port=8122,
             username=self.name,
             password=self.token,
@@ -185,6 +192,9 @@ class Scheduler(Process):
         self.address = "localhost:{}".format(self.sched_port)
         self.dashboard_address = "localhost:{}".format(self.dash_port)
 
+        # TODO: ugly... check sched status somehow
+        time.sleep(60)
+
         await super().start()
 
     async def close(self):
@@ -197,7 +207,7 @@ class Scheduler(Process):
         except Exception as ex:
             raise ex
 
-        cmd = "source ~/htc.rc; condor_rm {}.0".format(self.cluster_id)
+        cmd = "condor_rm {}.0".format(self.cluster_id)
 
         try:
             cmd_out = check_output(cmd, stderr=STDOUT, shell=True)
@@ -211,7 +221,9 @@ class Scheduler(Process):
 
 
 class RemoteHTCondor(SpecCluster):
-    def __init__(self, asynchronous=False):
+    def __init__(self, asynchronous=False, ssh_namespace="default"):
+        if os.environ.get("SSH_NAMESPACE"):
+            ssh_namespace = os.environ.get("SSH_NAMESPACE")
         self.sched_port = randrange(20000, 40000)
         self.dashboard_port = randrange(20000, 40000)
         sched = {
@@ -219,6 +231,7 @@ class RemoteHTCondor(SpecCluster):
             "options": {
                 "sched_port": self.sched_port,
                 "dashboard_port": self.dashboard_port,
+                "ssh_namespace": ssh_namespace,
             },
         }
         super().__init__(
